bl_info = {
    "name": "MultiBall Rig UI",
    "author": "Wayne Dixon",
    "version": (1, 1),
    "blender": (2, 80, 0),
    "location": "View3D > properties panel",
    "description": "display rig controls when selected (in pose mode)",
    "warning": "",
    "wiki_url": "",
    "category": "Animation"}

import bpy
rig_id = "Multiball_rig"


class VIEW3D_PT_rig_layers(bpy.types.Panel):
    bl_space_type = 'VIEW_3D'
    bl_region_type = 'UI'
    bl_category = 'Rig UI'
    bl_label = "MultiBall UI"

    @classmethod
    def poll(self, context):
        if context.mode != 'POSE':
            return False

        try:
           ob = context.active_object
           return (context.active_object.data.get("rig_id") == rig_id)
        except AttributeError:
           return 0

    def draw(self, context):
        layout = self.layout
        col = layout.column()

        # Layers
        row = col.row()
        row.prop(context.active_object.data, "layers", index=16, toggle=True, text="Root")
        row.prop(context.active_object.data, "layers", index=0, toggle=True, text="Body")

        row = col.row()
        row.prop(context.active_object.data, "layers", index=1, toggle=True, text="Squash")
        row.prop(context.active_object.data, "layers", index=2, toggle=True, text="Spin")

        row = col.row()
        row.separator()
        row = col.row()
        row.prop(context.active_object, 'show_in_front', toggle=True, text='X Ray')  
 
        row = col.row()
        row.separator()
        row = col.row()
        row.prop(context.active_object.pose.bones["Root"], '["Ball_type"]', text='Ball Type')
        row = col.row()
        row.prop(context.scene.render, "use_simplify", toggle=True,text="Simplify")
        if context.scene.render.use_simplify:
            row.prop(context.scene.render, "simplify_subdivision", text="levels")
        else:    
            row.label(text="")


def is_selected(context, names):
    try:
        for name in names:
            if context.active_pose_bone.name == name:
                return True
        for bone in context.selected_pose_bones:
            for name in names:
                if bone.name == name:
                    return True
    except AttributeError:
        pass
    return False


# Registration
def register():
    bpy.utils.register_class(VIEW3D_PT_rig_layers)


def unregister():
    bpy.utils.unregister_class(VIEW3D_PT_rig_layers)

if __name__ == '__main__':
    register()
